@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import date, datetime
 import unittest
 import time
 import six
@@ -208,23 +208,25 @@ class TestClient(unittest.TestCase):
 
     def test_flush(self):
         client = self.client
-        # send a few more requests than a single batch will allow
-        for i in range(60):
+        # set up the consumer with more requests than a single batch will allow
+        for i in range(1000):
             success, msg = client.identify('userId', { 'trait': 'value' })
-
-        self.assertFalse(client.queue.empty())
+        # We can't reliably assert that the queue is non-empty here; that's
+        # a race condition. We do our best to load it up though.
         client.flush()
+        # Make sure that the client queue is empty after flushing
         self.assertTrue(client.queue.empty())
 
     def test_overflow(self):
         client = Client('testsecret', max_queue_size=1)
-        client.consumer.pause()
-        time.sleep(5.1) # allow time for consumer to exit
+        # Ensure consumer thread is no longer uploading
+        client.join()
 
         for i in range(10):
           client.identify('userId')
 
         success, msg = client.identify('userId')
+        # Make sure we are informed that the queue is at capacity
         self.assertFalse(success)
 
     def test_success_on_invalid_write_key(self):
@@ -242,4 +244,18 @@ class TestClient(unittest.TestCase):
         self.assertFalse(self.failed)
 
     def test_debug(self):
-        Client('bad_key', debug=True)
\ No newline at end of file
+        Client('bad_key', debug=True)
+
+    def test_identify_with_date_object(self):
+        client = self.client
+        success, msg = client.identify(
+            'userId',
+            {
+                'birthdate': date(1981, 2, 2),
+            },
+        )
+        client.flush()
+        self.assertTrue(success)
+        self.assertFalse(self.failed)
+
+        self.assertEqual(msg['traits'], {'birthdate': date(1981, 2, 2)})
